#
# spec file for package mpDris2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mpDris2
Version:        0.9.1
Release:        3.1
Summary:        MPRIS V2.1 support for mpd
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/eonpatapon/mpDris2
Source:         https://github.com/eonpatapon/mpDris2/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         interpreter.patch
BuildRequires:  autoconf
BuildRequires:  automake
# g-i-devel: This is for automatic GObject Introspection bindings dependency generation:
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  python3-base
Requires:       python3-python-mpd2
Recommends:     %{name}-lang
BuildArch:      noarch
%{perl_requires}

%description
mpDris2 provide MPRIS 2 support to mpd (Music Player Daemon). mpDris2 is
run in the user session and monitors a local or distant mpd server.

%lang_package

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}

%files
%doc %{_docdir}/%{name}
%{_sysconfdir}/xdg/autostart/mpdris2.desktop
%{_bindir}/mpDris2
%{_userunitdir}/mpDris2.service
%{_datadir}/applications/mpdris2.desktop
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/services/org.mpris.MediaPlayer2.mpd.service

%files lang -f %{name}.lang

%changelog
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.1:
  * Use journald when using systemd service
  * Bug fixes
  * Drop python2 support
  * Support `~` expansion in configuration file
  * Added -j option to use systemd journald
* Sun Apr 14 2019 Sébastien 'sogal' Poher <sogal@opensuse.org>
- Updated to release 0.8:
  * Added cli options for mpd host and port, music dir
  * Better detection of embedded covers
  * Compatibility with python-mpd2 1.0.0
  * Fixed volume reporting with newer mpd versions
  * Fix notification system initialization
  * Notify urgengy can be configured
  * "Playing" and "Paused" notifications now show song information (gh-#71).
  * Path to config file can be changed via command line
  * Add a hidden option to change the D-Bus service name, for advanced
    multi-instance configurations.
* Sun Dec 23 2018 sogal@opensuse.org
- Fix interpreter.patch
* Sun Dec 23 2018 sogal@opensuse.org
- Update to current Github version, including the following:
  * Catch Mutagen exceptions for malformed files
  * Allow a custom bus name to be specified (for multi-instance)
  * Use SafeConfigParser#read() and Python3 interpreter
* Mon Aug 20 2018 luc14n0@linuxmail.org
- Add missing gobject-introspection-devel BuildRequires for
  automatic typelib requirements generation.
- Add python3-base BuildRequires and switch python2-python-mpd2
  Requires to python3-python-mpd2 since configure script checks for
  Python 3, the new openSUSE default version, rather than Python 2.
- Switch python2 to python3 in interprter.patch to reflect the
  previous changes.
- Drop update-desktop-files BuildRequires: this is not required nor
  used.
* Tue May  8 2018 sogal@volted.net
- Fix python-mpd module version
- Add interpreter.patch to fix env related warning
* Mon Sep 11 2017 mpluskal@suse.com
- Cleanup spec file and fix download url
* Mon Sep 11 2017 sogal@volted.net
- Initial build
